#ifndef BROKENPRINTER_H
#define BROKENPRINTER_H

#include "SbPreCompile.h" //QTimer

namespace Ui {
class BrokenPrinter;
}

/*!
 * \brief The CellAutomator class 优化修复主窗口。
 */
class BrokenPrinter : public QMainWindow
{
    Q_OBJECT

public:
    void emitShouldStartDetectForUnknownPhotoForGroupIdentify(QString trsdcardfacePhotojpgargrandomNumber); //!<发射信号，应当开始针对未知照片进行人脸检测。用于分组识别。

    explicit BrokenPrinter(QWidget *parent = 0);
    ~BrokenPrinter();

protected:
    void changeEvent(QEvent *e);

private:
    static BrokenPrinter * theSharedInstance; //!<The shared instance.
    static int imageCounter; //!<拍摄的图片计数器。

#ifdef Q_OS_ANDROID

    static void receivePhoto(JNIEnv * env, jobject thiz , jint applicationVersion); //!<接收照片。
    static void receivePhotoForPerson(JNIEnv * env, jobject thiz , jint applicationVersion); //!<接收照片。为人物接收照片。
    static void receiveUnknownPhoto(JNIEnv * env, jobject thiz , jint applicationVersion); //!<接收照片。未知照片。
    static void receiveUnknownPhotoForGroupIdentify(JNIEnv * env, jobject thiz , jint applicationVersion); //!<接收照片。未知照片。用于分组识别。


#endif

    void registerNativeMethods(); //!<注册原生方法。
    void jniTakeOnePhoto(); //!<以JNI方式来拍摄照片。
    void jniTakeOnePhotoForPerson(); //!<以JNI方式来拍摄照片。
    void jniTakeOneUknownPhoto(); //!<以JNI方式来拍摄照片。未知照片。
    void jniTakeOneUknownPhotoForGroupIdentify(); //!<以JNI方式来拍摄照片。未知照片。用于分组识别。
    QCameraViewfinder * viewfinder; //!<相机预览。
    bool checkCameraAvailability(); //!<检测相机。
    int personCounter=0; //!<人物计数器。
    QString unknownImagefaceId; //!<未知图片的人脸编号。
    QStringList unknownImageIdentifyfaceId; //!<未知图片的人脸编号列表。用于识别及后面的验证。
    QString unknownPhotoImagefaceId; //!<未知图片的人脸编号。照片。
    QString trainingSessionId; //!<训练的会话编号。
    QString trainingIdentifySessionId; //!<识别训练的会话编号。
    QString trainingPhotoSessionId; //!<训练的会话编号。照片。
    QString trainingGroupId; //!<训练的分组编号。
    QString trainingPersonId; //!<训练的人物编号。
    QString trainingPhotoPersonId; //!<训练的人物编号。照片。
    int verifyFaceCounter=0; //!<验证时的人脸计数器。
    int trainingDetectSucceededImageAmount=0; //!<训练成功图片个数。
    int trainingDetectSucceededPhotoImageAmount=0; //!<训练成功图片个数。照片。
    int trainingDetectFailedImageAmount=0; //!<训练失败图片个数。
    int trainingDetectFailedPhotoImageAmount=0; //!<训练失败图片个数。照片。

    QMap<QNetworkReply*,QString> trainingNetworkReplyFaceFileNameMap; //!<训练之前的人脸检测中，回复对象与图片文件名之间的映射。
    QMap<QNetworkReply*,QString> trainingNetworkReplyPhotoFaceFileNameMap; //!<训练之前的人脸检测中，回复对象与图片文件名之间的映射。
    QStringList imagesToTrainFileName; //!<要参与训练的图片文件名列表。
    QStringList photoImagesToTrainFileName; //!<要参与训练的照片文件名列表。
    QString unknownImageToVerifyFileName; //!<要验证的未知人脸的图片文件名。
    QString unknownPhotoImageToVerifyFileName; //!<要验证的未知人脸的图片文件名。照片。
    QString unknownImageToIdentifyFileName; //!<要识别的未知人脸的图片文件名。
    QString face1ImageToDetectFileName; //!<要上传进行检测的1号人脸图片文件名。
    QString face2ImageToDetectFileName; //!<要上传进行检测的2号人脸图片文件名。
    QString imageToDetectFileName; //!<要上传进行检测的图片文件名。
    QPixmap face2ImagePixmap; //!<2号人脸检测图片。
    QPixmap face1ImagePixmap; //!<1号人脸检测图片。
    QByteArray  imgContent; //!<图片文件内容。
    QString face1Id; //!<1号人脸的人脸编号。
    QString face2Id; //!<2号人脸的人脸编号。
    QStringList trainingFaceIdList; //!<训练前检测到的人脸编号列表。
    QStringList photoTrainingFaceIdList; //!<训练前从照片中检测到的人脸编号列表。
    QPixmap unknownImagePixmap; //!<未知的待验证图片。
    QPixmap unknownPhotoImagePixmap; //!<未知的待验证图片。照片。
    QPixmap unknownImageIdentifyPixmap; //!<未知的待识别图片。
    QNetworkAccessManager networkAccessManager; //!<网络访问管理器。
    void connectSignals(); //!<连接信号。
    void initializeMembers(); //!<初始化成员变量。
    Ui::BrokenPrinter *ui; //!<用户界面。

private slots:
    void selectTextFile(); //!<选择文本文件。
    void takeOnePhoto(); //!<拍摄一张照片。
    void takeOneUnknownPhoto(); //!<拍摄一张未知照片。

signals:
    void shouldStartDetectForUnknownPhotoForGroupIdentify( QString trsdcardfacePhotojpgargrandomNumber); //!<信号。应当开始针对未知照片进行人脸检测。用于分组识别。

    void photoCollected(QString sdcardfacePhotojpgargrandomNumber); //!<信号，已经收集了1张照片。
}; //class CellAutomator : public QMainWindow

#endif // CELLAUTOMATOR_H

